==> fsd-0.0.351.tar.gz: fsd-0.0.351/fsd/Deployment/DeploymentControllerAgent.py <==
import os
import sys
import random
import string
from .DeploymentCheckAgent import DeploymentCheckAgent

sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
from fsd.log.logger_config import get_logger

logger = get_logger(__name__)

class DeploymentControllerAgent:
    def __init__(self, repo):
        self.repo = repo
        self.deploymentCheckAgent = DeploymentCheckAgent(repo)

    async def get_started_deploy_pipeline(self):
        logger.info("\n #### `Deploy Agent` is checking if the current project is eligible for deployment")
        check_result = await self.deploymentCheckAgent.get_deployment_check_plans()
        result = check_result.get('result')
        
        if result in ["0", 0]:
            logger.info("\n #### `Deploy Agent` has determined that this project is not supported for deployment at this time!")
        elif result in ["1", 1]:
            path = check_result.get('full_project_path')
            if path != "null":
                logger.info("\n #### This project is eligible for deployment. `Deploy Agent` is proceeding with deployment now.")
                # Generate a valid subdomain name
                valid_chars = string.ascii_lowercase + string.digits + '-'
                name_subdomain = ''.join(random.choices(valid_chars, k=random.randint(5, 15)))
                
                # Ensure the subdomain doesn't start or end with a hyphen
                name_subdomain = name_subdomain.strip('-')
                
                # Ensure the subdomain is at least 2 characters long
                while len(name_subdomain) < 2:
                    name_subdomain += random.choice(string.ascii_lowercase)
                
                # Ensure the subdomain is no longer than 63 characters (DNS limitation)
                name_subdomain = name_subdomain[:63]
                self.repo.deploy_to_server(path, name_subdomain)
                logger.info(f"\n #### Your project is live here: [https://{name_subdomain}.zinley.xyz](https://{name_subdomain}.zinley.xyz)")
                logger.info("\n #### Deployment successful!")
            else:
                logger.info("\n #### Unable to deploy. Please try again!")

==> fsd-0.0.352.tar.gz: fsd-0.0.352/fsd/Deployment/DeploymentControllerAgent.py <==
import os
import sys
import random
import string
from .DeploymentCheckAgent import DeploymentCheckAgent

sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
from fsd.log.logger_config import get_logger

logger = get_logger(__name__)

class DeploymentControllerAgent:
    def __init__(self, repo):
        self.repo = repo
        self.deploymentCheckAgent = DeploymentCheckAgent(repo)

    async def get_started_deploy_pipeline(self):
        logger.info("\n #### `Deploy Agent` is checking if the current project is eligible for deployment")
        check_result = await self.deploymentCheckAgent.get_deployment_check_plans()
        result = check_result.get('result')
        
        if result in ["0", 0]:
            logger.info("\n #### `Deploy Agent` has determined that this project is not supported for deployment at this time!")
        elif result in ["1", 1]:
            path = check_result.get('full_project_path')
            if path != "null":
                logger.info("\n #### This project is eligible for deployment. `Deploy Agent` is proceeding with deployment now.")
                # Generate a valid subdomain name
                valid_chars = string.ascii_lowercase + string.digits + '-'
                name_subdomain = ''.join(random.choices(valid_chars, k=random.randint(5, 15)))
                
                # Ensure the subdomain doesn't start or end with a hyphen
                name_subdomain = name_subdomain.strip('-')
                
                # Ensure the subdomain is at least 2 characters long
                while len(name_subdomain) < 2:
                    name_subdomain += random.choice(string.ascii_lowercase)
                
                # Ensure the subdomain is no longer than 63 characters (DNS limitation)
                name_subdomain = name_subdomain[:63]
                self.repo.deploy_to_server(path, name_subdomain)
                logger.info(f"\n #### Your project is live here: [https://{name_subdomain}.zinley.xyz](https://{name_subdomain}.zinley.xyz){{:target=\"_blank\"}}")
                logger.info("\n #### Deployment successful!")
            else:
                logger.info("\n #### Unable to deploy. Please try again!")
